@@ -666,6 +666,7 @@ inline int _ConvertSMVer2Cores(int major, int minor) {
       {0x80,  64},
       {0x86, 128},
       {0x87, 128},
+      {0x90, 128},
       {-1, -1}};
 
   int index = 0;
@@ -712,6 +713,8 @@ inline const char* _ConvertSMVer2ArchName(int major, int minor) {
       {0x75, "Turing"},
       {0x80, "Ampere"},
       {0x86, "Ampere"},
+      {0x87, "Ampere"},
+      {0x90, "Hopper"},
       {-1, "Graphics Device"}};
 
   int index = 0;
